<?php
  /**
  * Query Amazon servers for product.
  * 
  * @param mixed $PrivateKey
  * @param mixed $PublicKey
  * @param string $parameters
  * @param mixed $amz_region
  * @param mixed $Version
  * @return object
  */
  function get_AWS_request($PrivateKey, $PublicKey, $parameters, $amz_region, $Version = "2009-03-31")
  {
      //Enable standard libxml error handling.
      libxml_use_internal_errors(true);
      //Set up our URI to point to the XML handler on the amazonaws host servers.
      $path = "/onca/xml";
      $host = "ecs.amazonaws." . $amz_region;
      //Use GET method.
      $method = "GET";
      //Set time.            
      $t = time() + 10000;
      $parameters["Timestamp"] = gmdate("Y-m-d\TH:i:s\Z", $t);
      $parameters["AWSAccessKeyId"] = $PublicKey;
      $parameters["Version"] = $Version;
      $parameters["Service"] = "AWSECommerceService";
      //Key sort for formatted output.
      ksort($parameters);
      //Setup our string for signing.
      $CanonicalizedQuery = getCanonicalQuery($parameters, $path, $host, $method);
      $string_to_sign = $method . "\n" . $host . "\n" . $path . "\n" . $CanonicalizedQuery;
      $signature = base64_encode(hash_hmac("sha256", $string_to_sign, $PrivateKey, true));
      $signature = str_replace("%7E", "~", rawurlencode($signature));
      $request = "http://" . $host . $path . "?" . $CanonicalizedQuery . "&Signature=" . $signature;
      //Attempt to get the response from the requested URI.
      $response = getResponse($request);
      if (isset($response["error"]["message"])) {
          return $response;
      } else {
          $Xml = simplexml_load_string($response);
          if ($Xml === false) {
              $emessage = __("Failed loading XML, errors returned: ");
              foreach (libxml_get_errors() as $error) {
                  $emessage .= $error->message . ", ";
              }
              libxml_clear_errors();
              $return ["error"]["message"] = $emessage;
              return $return;
          } else {
              return $Xml;
          }
      }
  }
  
  /**
  * Create a canonicalized query based on input.
  * 
  * @param mixed $parameters
  * @param mixed $path
  * @param mixed $host
  * @param mixed $method
  */
  function getCanonicalQuery($parameters, $path, $host, $method)
  {
      //Set as an error/empty.
      $CanonicalizedQuery = array();
      foreach ($parameters as $data => $value) {
          $data = str_replace("%7E", "~", rawurlencode($data));
          $value = str_replace("%7E", "~", rawurlencode($value));
          $CanonicalizedQuery[] = $data . "=" . $value;
      }
      $CanonicalizedQuery = implode("&", $CanonicalizedQuery);
      return $CanonicalizedQuery;
  }
  
  /**
  * Get response message from requested URI.
  * 
  * @param mixed $request
  * @return string
  */
  function getResponse($request)
  {
      //Check if cURL will be available for use
      if (function_exists('curl_init')) {
          //Create a new cURL instance
          $ch = curl_init();
          //Set up our user-agent and other cURL variables
          curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (compatible; Konqueror/4.0; Microsoft Windows) KHTML/4.0.80 (like Gecko)");
          curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
          curl_setopt($ch, CURLOPT_URL, $request);
          curl_setopt($ch, CURLOPT_TIMEOUT, 60);
          //Execute and save cURL response
          $response = curl_exec($ch);
          //Close cURL session to free up memory.                      
          curl_close($ch);
          if (!$response) {
              //Got invalid response! Set error--message with associated errors.   
              $return ["error"]["message"] = __("Error By cURL Error Detail : ") . curl_errno($ch) . ": " . curl_error($ch);
              return $return;
          } else {
              //Everything was gravy, let's return that.
              return $response;
          }
      } else {
          //cURL doesn't work, attempt old fashioned way.
          $response = @file_get_contents($request);
          if (!$response) {
              //We can't even use cURL! This isn't going to work. Return server error.  
              $return ["error"]["message"] = __("Server Error : cURL is not exist on this server!");
              return $return;
          } else {
              //Was able to get data via file_get_contents.
              return $response;
          }
      }
  }
  
  /**
  * Create postable. Not exactly sure what this does.
  * 
  * @param mixed $itype
  * @param mixed $itime
  * @param mixed $category
  * @param mixed $keys
  * @param mixed $postnow
  * @param mixed $department
  * @param mixed $numofpost
  * @param mixed $AffiliateId
  * @param mixed $cam_encoding
  * @param mixed $browsenode
  * @param mixed $CampaignID
  * @param mixed $minprice
  * @param mixed $parent_page
  * @param mixed $asin_code
  * @return object
  */
  function build_postable($itype, $itime, $category, $keys, $postnow, $department, $numofpost, $AffiliateId, $cam_encoding = 0, $browsenode = 0, $CampaignID = 0, $minprice = 0, $parent_page = 0, $asin_code = "")
  {
      global $wpdb; 
      $first_count = 0;
      $error_count = 0;
      $emassage = array();
      $product_error = "";
      $countpost = array();
      $finished = false;
      $page = 1;
      if (!ini_get('safe_mode')) {
        if (@ini_get('memory_limit') != '256M') {
            @ini_set('memory_limit', '256M');
        }
        @set_time_limit(0);
      }
      $sql_product = "SELECT cam_camproductid FROM " . $wpdb->prefix . "ama_campaigns_post, `" . $wpdb->prefix . "posts` WHERE `post_ID` = `ID` AND `post_status` IN ('publish','future')";
      $productid = $wpdb->get_results($sql_product);
      $data_product = array();
      $count = 0;
      foreach ($productid as $id) {
          $data_product[] = $id->cam_camproductid;
          $count++;
      }
      $time = $itime;
      $sql = "SELECT * FROM " . $wpdb->prefix . "ama_option ";
      //Query Amazon APIs.
      $api_data = $wpdb->get_results($sql);
      foreach ($api_data as $data) {
          $des_length = $data->amazon_des_length;
          $aff_web = $data->amazon_web;
          $PublicKey = $data->api_key;
          $PrivateKey = $data->secret_api_key;
      }
      //Get the category's id.
      $categoryID = get_term_by('name', $category, 'category');
      $post_category = array($categoryID->term_id);
      do {
          usleep(1200000);
          if (!empty($asin_code)) {
              $xml = get_AWS_request($PrivateKey, $PublicKey, array("Operation" => "ItemLookup", "ItemId" => $asin_code, "ResponseGroup" => "Large,VariationSummary", "AssociateTag" => $AffiliateId), $aff_web);
          } else {
              if ($department == "All") {
                  $xml = get_AWS_request($PrivateKey, $PublicKey, array("Operation" => "ItemSearch", "IdType" => "ASIN", "MerchantId" => "All", "ResponseGroup" => "Large,VariationSummary", "SearchIndex" => $department, "Keywords" => $keys, "ItemPage" => $page, "AssociateTag" => $AffiliateId), $aff_web);
              } elseif (!empty($browsenode)) {
                  $xml = get_AWS_request($PrivateKey, $PublicKey, array("Operation" => "ItemSearch", "IdType" => "ASIN", "MerchantId" => "All", "ResponseGroup" => "Large,VariationSummary", "BrowseNode" => $browsenode, "SearchIndex" => $department, "Keywords" => $keys, "ItemPage" => $page, "AssociateTag" => $AffiliateId), $aff_web);
              } else {
                  $xml = get_AWS_request($PrivateKey, $PublicKey, array("Operation" => "ItemSearch", "IdType" => "ASIN", "MerchantId" => "All", "ResponseGroup" => "Large,VariationSummary", "SearchIndex" => $department, "Keywords" => $keys, "ItemPage" => $page, "AssociateTag" => $AffiliateId), $aff_web);
              }
          }
          //If error, log and kill execution.
          if (isset($xml->Error->Code) || isset($xml['error']['message'])) {
              if (isset($xml->Error->Code)) {
                  $emassage['message'] = '<b>' . $xml->Error->Code . '<br />Please Check your AWS Secret Access Key and signing method</b><br/>';
              } else {
                  $emassage['message'] = '<b>Host not found</b>';
              }
              //We are done here.
              $finished = true;
          } else {
              $qry = 'SELECT * FROM ' . $wpdb->prefix . 'wpd_general_settings LIMIT 1';
              $option_data = $wpdb->get_row($qry);
              $enabe_review_only_post = $option_data->enabe_review_only_post;
              $enable_link_cloaking = $option_data->enable_link_cloaking;
              foreach ($xml->Items->Item as $item) {
                  $ListPrice = null;
                  $LowestPrice = null;
                  $ListPrice = $item->ItemAttributes->ListPrice->FormattedPrice;
                  $LowestPrice = $item->OfferSummary->LowestNewPrice->FormattedPrice;
                  //Loop through lowest price and set variable accordingly.
                  if ($LowestPrice == null) {
                      $LowestPrice = $item->Offers->Offer->OfferListing->Price->FormattedPrice;
                  }
                  if ($LowestPrice == null) {
                      $LowestPrice = $item->OfferSummary->LowestUsedPrice->FormattedPrice;
                  }
                  if ($LowestPrice == null) {
                      $LowestPrice = $item->OfferSummary->LowestNewPrice->FormattedPrice;
                  }
                  if ($LowestPrice == null) {
                      $LowestPrice = $item->OfferSummary->LowestNewPrice->FormattedPrice;
                  }
                  if ($LowestPrice == null) {
                      $LowestPrice = $item->VariationSummary->LowestPrice->FormattedPrice;
                  }
                  if ($ListPrice == null) {
                      $ListPrice = $item->VariationSummary->HighestPrice->FormattedPrice;
                  }
                  if ($LowestPrice == null) {
                      $LowestPrice = $ListPrice;
                  }
                  $pricetypearray = array('$', '', 'EUR', ',', 'CDN', '?');
                  $price = (float)str_replace($pricetypearray, '', $LowestPrice);
                  if (isset($item->EditorialReviews->EditorialReview->Content) && isset($item->MediumImage->URL[0]) && !(in_array($item->ASIN, $data_product)) && $LowestPrice != null && $price >= $minprice) {
                      if ($itype == "day") {
                          $new_time = mktime(date("H"), date("i"), date("s"), date("m"), date("d") + $time, date("y"));
                      } elseif ($itype == "hours") {
                          $new_time = mktime(date("H") + $time, date("i"), date("s"), date("m"), date("d"), date("y"));
                      } else {
                          $new_time = mktime(date("H"), date("i") + $time, date("s"), date("m"), date("d"), date("y"));
                      }
                      $time = $time + $itime;
                      $post_date = date('Y-m-d H:i:s', $new_time);
                      $post_date_gmt = date('Y-m-d H:i:s', $new_time);
                      $post_status = 'future';
                      if ($postnow == "yes" && empty($first_count)) {
                          $post_status = 'publish';
                          $post_date = current_time('mysql');
                          $post_date_gmt = current_time('mysql', 1);
                          $first_count = 1;
                      }
                      $htacessurl = get_bloginfo('home') . '/product/' . $item->ASIN . '/';
                      $post_title = $item->ItemAttributes->Title[0];
                      $kappa = ($enabe_review_only_post == 1) ? $post_title : "&nbsp;";
                      if ($enable_link_cloaking == 1) {
                          $post_content = '<p style="float:left; margin-right:10px;"><a href="' . $htacessurl . '" rel="nofollow" target="_blank"><img src="' . $item->MediumImage->URL[0] . '" alt="' . $kappa . '"></a></p>';
                      } else {
                          $post_content = '<p style="float:left; margin-right:10px;"><a href="' . $item->DetailPageURL . '" rel="nofollow" target="_blank"><img src="' . $item->MediumImage->URL[0] . '" alt="' . $kappa . '"></a></p>';
                      }
                      $CONTENT = "";
                      $CONTENT = trim(substr(strip_tags($item->EditorialReviews->EditorialReview->Content[0]), 0, $des_length));
                      if (!empty($cam_encoding)) {
                          $CONTENT = wpd_obscure($CONTENT);
                      }
                      $post_content .= '<p>' . substr($CONTENT, 0, strrpos($CONTENT, ' ')) . '<br/></p>';
                      $post_content .= '<div>Sale Price:<span class="amazon_saleprice">' . str_replace('', "", $LowestPrice) . '</span></div>';
                      if ($enable_link_cloaking == 1) {
                          $post_content .= '<p><a href="' . $htacessurl . '" rel="nofollow" target="_blank">Read More</a><a style="float:right" href="' . $htacessurl . '" rel="nofollow" target="_blank"><img src="' . AMAZON_URL . '/color/buy_now.jpg" alt="buy now"></a></p>';
                      } else {
                          $post_content .= '<p><a href="' . $item->DetailPageURL . '" rel="nofollow" target="_blank">Read More</a><a style="float:right" href="' . $item->DetailPageURL . '" rel="nofollow" target="_blank"><img src="' . AMAZON_URL . '/color/buy_now.jpg" alt="buy now"></a></p>';
                      }
                      $items = explode(' ', $post_title);
                      $thetag = array();
                      for ($k = 0, $l = count($items); $k < $l; ++$k) {
                          $long = strlen($items[$k]);
                          if ($long >= 2) {
                              $thetag[] = $items[$k];
                          }
                      }
                      $tags_input = array();
                      for ($i = 0; $i <= 9; $i++) {
                        $tags_input[] = $thetag[$i];
                      }
                      $post_author = 1;
                      $post_data = compact('post_content', 'post_title', 'post_date', 'post_date_gmt', 'post_author', 'post_category', 'post_status', 'tags_input');
                      $post_data = add_magic_quotes($post_data);
                      $post_ID = wp_insert_post($post_data);
                      if ($parent_page > 0) {
                          $parent_pages = get_post_meta($parent_page, 'page_loader', true);
                          if ($parent_pages == "") {
                              $parent_pages = array($post_ID);
                              add_post_meta($parent_page, 'page_loader', implode(",", $parent_pages), true);
                          } else {
                              $parent_pages = explode(",", $parent_pages);
                              $parent_pages[] = $post_ID;
                              $parent_pages = array_filter($parent_pages);
                              update_post_meta($parent_page, 'page_loader', implode(",", $parent_pages));
                          }
                      }
                      $countpost[] = array('ASIN' => $item->ASIN, 'post_ID' => $post_ID);
                      if ($enable_link_cloaking == 1) {
                          $mira = get_bloginfo('home');
                          $mir = get_bloginfo('home');
                          $miri = "http://" . $_SERVER['HTTP_HOST'];
                          $miniz = str_replace($miri, "", $mira);
                          $htacessdata = "\n\r" . 'redirect 301 ' . $miniz . '/product/' . $item->ASIN . '/  ' . str_replace(" ", "", $item->DetailPageURL) . "\n\r";
                          //Grab the htacess handle
                          $handle = writeToHT($htacessdata);
                      }
                      //Check to see if we are finished processing posts.
                      if (count($countpost) >= $numofpost) {
                          $break = true;
                          $finished = true;
                          break; //Step out of loop.
                      }
                  }
              }
              if ($page >= 49) {
                  if (count($countpost) <= 4) {
                      $finished = true;
                  }
              }
          }
          $page++;
      } while (!($finished));
      //Done looping, close htacess.
      if (!empty($handle)) {
          saveHT($handle);
      }
      if (count($countpost) == 0 && count($emassage) == 0 && !(isset($emassage['message']))) {
          $emassage['message'] = '<b>No product return Please enter valid keyword</b><br/>';
      }
      if (count($emassage) == 0) {
          for ($i = 0; $i < count($countpost); $i++) {
              $sql_insert = "INSERT INTO " . $wpdb->prefix . "ama_campaigns_post(cam_postid,cam_camid,cam_camproductid,post_ID,cam_capiid)values(null,'" . $CampaignID . "','" . $countpost[$i]['ASIN'] . "','" . $countpost[$i]['post_ID'] . "','" . $AffiliateId . "')";
              $wpdb->query($sql_insert);
          }
      }
      $emassage['num_post'] = count($countpost);
      return $emassage;
  }
  
  /**
  * Find or create a .htaccess file to write to.
  * 
  * @param mixed $data
  * @return object
  */
  function writeToHT($data)
  {
      $filepath = dirname(__FILE__) . "/../../../.htaccess";
      //Find/Create file
      $filehtacess = fopen($filepath, "a");
      fwrite($filehtacess, $data);
      return $filehtacess;
  }
  
  /**
  * Simply close via handle.
  * 
  * @param mixed $filehtacess
  */
  function saveHT($filehtacess)
  {
      fclose($filehtacess); //Boom!
  }
?>