<?php
/*-----------------------------------------------------------------------------------

CLASS INFORMATION

Description: A custom WooThemes 250px Ads widget.
Date Created: 2011-07-11.
Last Modified: 2011-07-11.
Author: WooThemes.
Since: 2.9.0


TABLE OF CONTENTS

- var $woo_widget_cssclass
- var $woo_widget_description
- var $woo_widget_idbase
- var $woo_widget_title

- function (constructor)
- function widget ()
- function update ()
- function form ()

- Register the widget on `widgets_init`.

-----------------------------------------------------------------------------------*/

class Woo_Widget_Ads_250 extends WP_Widget {

	/*----------------------------------------
	  Variable Declarations.
	  ----------------------------------------
	  
	  * Variables to setup the widget.
	----------------------------------------*/

	var $woo_widget_cssclass;
	var $woo_widget_description;
	var $woo_widget_idbase;
	var $woo_widget_title;

	/*----------------------------------------
	  Constructor.
	  ----------------------------------------
	  
	  * The constructor. Sets up the widget.
	----------------------------------------*/
	
	function Woo_Widget_Ads_250 () {
	
		/* Widget variable settings. */
		$this->woo_widget_cssclass = 'widget_woo_ads_250';
		$this->woo_widget_description = __( 'This is a WooThemes standardized 250x250 Adspace widget.', 'woothemes' );
		$this->woo_widget_idbase = 'advert_250x250';
		$this->woo_widget_title = __('Woo - Ads 250x250', 'woothemes' );
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->woo_widget_cssclass, 'description' => $this->woo_widget_description );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => $this->woo_widget_idbase );

		/* Create the widget. */
		$this->WP_Widget( $this->woo_widget_idbase, $this->woo_widget_title, $widget_ops, $control_ops );
		
	} // End Constructor

	/*----------------------------------------
	  widget()
	  ----------------------------------------
	  
	  * Displays the widget on the frontend.
	----------------------------------------*/

	function widget( $args, $instance ) {  
		
		$html = '';
		
		extract( $args, EXTR_SKIP );
		
		/* Our variables from the widget settings. */
		$ad_250_adsense = get_option( 'woo_ad_250_adsense' );
		
		$before_widget = str_replace( 'class="widget', 'class="widget wrap', $before_widget );
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		if ( $ad_250_adsense != '' ) {
			$html .= stripslashes( $ad_250_adsense );
		} else {
			$html .= '<a href="' . get_option( 'woo_ad_250_url' ) . '"><img src="' . get_option( 'woo_ad_250_image' ) . '" width="250" height="250" alt="advert" /></a>' . "\n";
		}
		
		echo $html; // If using the $html variable to store the output, you need this. ;)
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_bottom' );

		/* After widget (defined by themes). */
		echo $after_widget;

	} // End widget()

   /*----------------------------------------
	 form()
	 ----------------------------------------
	  
	  * The form on the widget control in the
	  * widget administration area.
	  
	  * Make use of the get_field_id() and 
	  * get_field_name() function when creating
	  * your form elements. This handles the confusing stuff.
	  
	  * Params:
	  * - Array $instance
	----------------------------------------*/

   function form( $instance ) {       

?>
		<!-- Widget Notice -->
		<p>
			<?php printf( __( 'This widget\'s settings are controlled via %s.', 'woothemes' ), '<a href="' . admin_url( 'admin.php?page=woothemes' ) . '">' . __( 'Theme Options', 'woothemes' ) . '</a>' ); ?>
		</p><?php
	} // End form()
	
} // End Class

/*----------------------------------------
  Register the widget on `widgets_init`.
  ----------------------------------------
  
  * Registers this widget.
----------------------------------------*/

add_action( 'widgets_init', create_function( '', 'return register_widget("Woo_Widget_Ads_250");' ), 1 ); 
?>