<?php
/*-----------------------------------------------------------------------------------

CLASS INFORMATION

Description: A custom WooThemes Ads widget.
Date Created: 2011-07-11.
Last Modified: 2011-07-11.
Author: WooThemes.
Since: 2.9.0


TABLE OF CONTENTS

- var $woo_widget_cssclass
- var $woo_widget_description
- var $woo_widget_idbase
- var $woo_widget_title

- function (constructor)
- function widget ()
- function update ()
- function form ()

- Register the widget on `widgets_init`.

-----------------------------------------------------------------------------------*/

class Woo_AdWidget extends WP_Widget {

	/*----------------------------------------
	  Variable Declarations.
	  ----------------------------------------
	  
	  * Variables to setup the widget.
	----------------------------------------*/

	var $woo_widget_cssclass;
	var $woo_widget_description;
	var $woo_widget_idbase;
	var $woo_widget_title;

	/*----------------------------------------
	  Constructor.
	  ----------------------------------------
	  
	  * The constructor. Sets up the widget.
	----------------------------------------*/
	
	function Woo_AdWidget () {
	
		/* Widget variable settings. */
		$this->woo_widget_cssclass = 'adspace-widget';
		$this->woo_widget_description = __( 'Use this widget to add any type of Ad as a widget.', 'woothemes' );
		$this->woo_widget_idbase = 'adspace';
		$this->woo_widget_title = __('Woo - Adspace Widget', 'woothemes' );
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->woo_widget_cssclass, 'description' => $this->woo_widget_description );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => $this->woo_widget_idbase );

		/* Create the widget. */
		$this->WP_Widget( $this->woo_widget_idbase, $this->woo_widget_title, $widget_ops, $control_ops );
		
	} // End Constructor

	/*----------------------------------------
	  widget()
	  ----------------------------------------
	  
	  * Displays the widget on the frontend.
	----------------------------------------*/

	function widget( $args, $instance ) {  
		
		$html = '';
		
		extract( $args, EXTR_SKIP );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'], $instance, $this->id_base );
		$adcode = $instance['adcode'];
		$image = $instance['image'];
		$href = $instance['href'];
		$alt = $instance['alt'];
			
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title ) {
		
			echo $before_title . $title . $after_title;
		
		} // End IF Statement
		
		/* Widget content. */
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_top' );
		
		// Load widget content here.
		$html = '';
		
		if ( $adcode != '' ) {
			$html .= $adcode;
		} else {
			$html .= '<a href="' . $href . '"><img src="' . $image . '" alt="' . $alt . '" /></a>' . "\n";
		}
		
		echo $html; // If using the $html variable to store the output, you need this. ;)
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_bottom' );

		/* After widget (defined by themes). */
		echo $after_widget;

	} // End widget()

	/*----------------------------------------
	  update()
	  ----------------------------------------
	
	* Function to update the settings from
	* the form() function.
	
	* Params:
	* - Array $new_instance
	* - Array $old_instance
	----------------------------------------*/
	
	function update ( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		
		/* The select box is returning a text value, so we escape it. */
		$instance['title'] = esc_attr( $new_instance['title'] );
		$instance['adcode'] = esc_attr( $new_instance['adcode'] );
		$instance['image'] = esc_attr( $new_instance['image'] );
		$instance['href'] = esc_url( $new_instance['href'] );
		$instance['alt'] = esc_attr( $new_instance['alt'] );
		
		return $instance;
		
	} // End update()

   /*----------------------------------------
	 form()
	 ----------------------------------------
	  
	  * The form on the widget control in the
	  * widget administration area.
	  
	  * Make use of the get_field_id() and 
	  * get_field_name() function when creating
	  * your form elements. This handles the confusing stuff.
	  
	  * Params:
	  * - Array $instance
	----------------------------------------*/

   function form( $instance ) {       
   
		/* Set up some default widget settings. */
		$defaults = array(
						'title' => '', 
						'adcode' => '', 
						'image' => '', 
						'href' => '', 
						'alt' => ''
					);
		
		$instance = wp_parse_args( (array) $instance, $defaults );
?>
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title (optional):', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"  value="<?php echo $instance['title']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" />
		</p>
		<!-- Widget Adcode: Textarea -->
		<p>
			<label for="<?php echo $this->get_field_id( 'adcode' ); ?>"><?php _e( 'Ad Code:', 'woothemes' ); ?></label>
			<textarea name="<?php echo $this->get_field_name( 'adcode' ); ?>" class="widefat" rows="5" id="<?php echo $this->get_field_id( 'adcode' ); ?>"><?php echo $instance['adcode']; ?></textarea>
		</p>
		<!-- Widget Image: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'image' ); ?>"><?php _e( 'Image URL:', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'image' ); ?>"  value="<?php echo $instance['image']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'image' ); ?>" />
			<?php  printf( __( 'Don\'t forget to include %s.', 'woothemes' ), '<code>http://</code>' ); ?>
		</p>
		<!-- Widget Href: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'href' ); ?>"><?php _e( 'Link URL:', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'href' ); ?>"  value="<?php echo $instance['href']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'href' ); ?>" />
			<?php printf( __( 'Don\'t forget to include %s.', 'woothemes' ), '<code>http://</code>' ); ?>
		</p>
		<!-- Widget Alt: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'alt' ); ?>"><?php _e( 'Alt Text:', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'alt' ); ?>"  value="<?php echo $instance['alt']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'alt' ); ?>" />
		</p>
<?php
	} // End form()
	
} // End Class

/*----------------------------------------
  Register the widget on `widgets_init`.
  ----------------------------------------
  
  * Registers this widget.
----------------------------------------*/

add_action( 'widgets_init', create_function( '', 'return register_widget("Woo_AdWidget");' ), 1 ); 
?>